#
# spec file for package arianna
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           arianna
Version:        23.08.5
Release:        bp156.1.2
Summary:        Ebook reader and library management app
License:        GPL-3.0-only
URL:            https://apps.kde.org/arianna/
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Baloo)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5FileMetaData)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5KirigamiAddons) >= 0.10
BuildRequires:  cmake(KF5QQC2DesktopStyle)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5WebEngine)
BuildRequires:  cmake(Qt5WebSockets)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
Requires:       kirigami-addons
Requires:       kirigami2
Requires:       kquickcharts
Requires:       libQt5Sql5-sqlite
Requires:       libqt5-qtquickcontrols2
# No QtWebEngine for other archs
ExclusiveArch:  %{arm} aarch64 %{ix86} x86_64 %{riscv}

%description
An ebook reader and library management app supporting ".epub" files. Arianna
discovers your books automatically, and sorts them by categories, genres and
authors.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build

%install
%kf5_makeinstall -C build

%find_lang %{name}

%files
%license LICENSES/*
%doc README.md
%{_kf5_applicationsdir}/org.kde.arianna.desktop
%{_kf5_appstreamdir}/org.kde.arianna.appdata.xml
%{_kf5_bindir}/arianna
%{_kf5_debugdir}/arianna.categories
%{_kf5_iconsdir}/hicolor/scalable/apps/org.kde.arianna.svg

%files lang -f %{name}.lang

%changelog
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 23.08.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.5/
- No code change since 23.08.4
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * CI: Comment out flatpak as it uses some KF6 dependencies
  * snapcraft: bump content pack version, remove deps now in content pack.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * snapcraft: Add dbus slot.
  * Add ecm package as it requires newer than content pack provides.
  * Add snapcraft file to resue
  * snapcraft: add snapcraft files
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Fix inconsistency in the sidebar
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
* Sun Jun 11 2023 Christophe Marin <christophe@krop.fr>
- Update to 1.1.0
  * Arianna can now display the table of content of a book
  * File metadata are now available
  * Fix: A network connection is no longer required
  * Fixed various crashes when indexing books
* Sun Apr 23 2023 Christophe Marin <christophe@krop.fr>
- Update to 1.0.1
  * Fix opening book with # or ? in their name
  * Fix keyboard navigation issues in library view
  * Clarify licensing of epub.js
  * Bump dependency on kirigami-addons to 0.8
  * Only set title if the list is not empty
  * Don't use processEvents
* Sun Apr 16 2023 Christophe Marin <christophe@krop.fr>
- Add kirigami-addons to runtime dependencies
* Fri Apr 14 2023 Christophe Marin <christophe@krop.fr>
- Initial version
